@@ -550,7 +550,9 @@ impl TimerDriver {
 
 impl Drop for TimerDriver {
     fn drop(&mut self) {
-        self.0.borrow_mut().stop_wheel();
+        if let Ok(mut timer) = self.0.try_borrow_mut() {
+            timer.stop_wheel();
+        }
     }
 }
 
@@ -608,7 +610,9 @@ impl LowresTimerDriver {
 
 impl Drop for LowresTimerDriver {
     fn drop(&mut self) {
-        self.0.borrow_mut().stop_wheel();
+        if let Ok(mut timer) = self.0.try_borrow_mut() {
+            timer.stop_wheel();
+        }
     }
 }
 
@@ -657,32 +661,32 @@ mod tests {
         let fut2 = sleep(Millis(200));
 
         fut2.await;
-        let elapsed = Instant::now() - time;
+        let _elapsed = Instant::now() - time;
         #[cfg(not(target_os = "macos"))]
         assert!(
-            elapsed > Duration::from_millis(200) && elapsed < Duration::from_millis(300),
+            _elapsed > Duration::from_millis(200) && _elapsed < Duration::from_millis(300),
             "elapsed: {:?}",
-            elapsed
+            _elapsed
         );
 
         fut1.await;
-        let elapsed = Instant::now() - time;
+        let _elapsed = Instant::now() - time;
         #[cfg(not(target_os = "macos"))]
         assert!(
-            elapsed > Duration::from_millis(1000)
-                && elapsed < Duration::from_millis(1200), // osx
+            _elapsed > Duration::from_millis(1000)
+                && _elapsed < Duration::from_millis(1200), // osx
             "elapsed: {:?}",
-            elapsed
+            _elapsed
         );
 
         let time = Instant::now();
         sleep(Millis(25)).await;
-        let elapsed = Instant::now() - time;
+        let _elapsed = Instant::now() - time;
         #[cfg(not(target_os = "macos"))]
         assert!(
-            elapsed > Duration::from_millis(20) && elapsed < Duration::from_millis(50),
+            _elapsed > Duration::from_millis(20) && _elapsed < Duration::from_millis(50),
             "elapsed: {:?}",
-            elapsed
+            _elapsed
         );
     }
 }
